/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.padre.client.PadreClientException;

/**
 * Abstract super class of all commands for communication
 * with the PaDRe interface.
 * @author Fabian Körner
 * @param <T> Different Requests return different types.
 */
abstract class AbstractPadreCommand<T>
{

	private PadreClient _padreClient;

	/**
	 * Default constructor. Fetches reference to an instance of PaDReClient
	 * and provides for use with subclasses.
	 * @throws PadreCommandException Client initialisation failed.
	 */
	public AbstractPadreCommand() throws PadreCommandException
	{
		try
		{
			_padreClient = PadreConfiguration.getInstance().getPadreClient();
		}
		catch (PadreClientException cause)
		{
			throw new PadreCommandException(cause);
		}
	}

	protected PadreClient getPadreClient()
	{
		return _padreClient;
	}

	/**
	 * Executes the implemented PaDRe command.
	 * @return Return type depends on implementation.
	 * @throws PadreCommandException Error during command execution.
	 */
	public abstract T execute() throws PadreCommandException;

}
