/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import org.bbaw.pdr.utils.Identifier;

/**
 * Checks the existence of a single PDR object via configured PaDRe interface.
 * @author Fabian Körner
 */
public final class PadreContains extends AbstractPadreCommand<Boolean>
{

	private Identifier _identifier;

	/**
	 * Checks the existence of the PDRObject with the given ID,
	 * provided as <code>java.lang.String</code>.
	 * @param identifier ID to be checked.
	 * @throws PadreCommandException Check failed.
	 */
	public PadreContains(final String identifier) throws PadreCommandException
	{
		super();
		try
		{
			_identifier = new Identifier(identifier);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}

	/**
	 * Checks the existence of the PDRObject with the given ID,
	 * provided as <code>org.bbaw.pdr.utils.Identifier</code>.
	 * @param identifier ID to be checked.
	 * @throws PadreCommandException Check failed.
	 */
	public PadreContains(final Identifier identifier) throws PadreCommandException
	{
		_identifier = identifier;
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Object exists.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public Boolean execute() throws PadreCommandException
	{
		Boolean result = null;
		try
		{
			result = super.getPadreClient().contains(_identifier.toPadreID());
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
		return result;
	}
}
