/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre.test;

import static org.junit.Assert.assertEquals;

import java.util.List;
import java.util.Vector;

import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.PadreGetIDRanges;
import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.padre.request.PadreID;
import org.bbaw.pdr.padre.request.PadreObject;
import org.bbaw.pdr.utils.IDRange;
import org.bbaw.pdr.utils.PDRType;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
*
* @author Fabian Körner
*/
public class TestPadreGetIDRanges
{

	private static final TestConfiguration CONFIGURATION = new TestConfigurationFromFile();

	private PadreClient _padreClient;

	/**
	 * @throws Exception Exception.
	 */
	@Before
	public final void setUp() throws Exception
	{
		PadreConfiguration.getInstance().setCredentials(CONFIGURATION.getUri(), CONFIGURATION.getUsername(), CONFIGURATION.getPassword());
		_padreClient = PadreConfiguration.getInstance().getPadreClient();

		_padreClient.createStore("31e");
		List<PadreObject> testObjects = new Vector<PadreObject>();
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000001")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000002")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000003")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.00000001f")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000020")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000021")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000022")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000023")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000024")));
		testObjects.add(TestPadreGetIDRanges.createTestObject(new PadreID("pdrAo.001.31e.000000025")));
		_padreClient.write(testObjects);

	}

	/**
	 * @throws Exception Exception.
	 */
	@After
	public final void tearDown() throws Exception
	{
		_padreClient.deleteStore("31e");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetIDRanges() throws Exception
	{
		PDRType type = PDRType.ASPECT;
		int instance = 1;
		int project = 798;
		int min = IDRange.MIN_OBJECT_ID;
		int max = IDRange.MAX_OBJECT_ID;

		List<IDRange> ranges = new PadreGetIDRanges(PDRType.ASPECT, instance, project, min, max).execute();
		assertEquals(2, ranges.size());

		IDRange range0 = ranges.get(0);
		assertEquals(type, range0.getType());
		assertEquals(instance, range0.getInstance());
		assertEquals(project, range0.getProject());
		assertEquals(1, range0.getLowerBound());
		assertEquals(3, range0.getUpperBound());

		IDRange range1 = ranges.get(1);
		assertEquals(type, range1.getType());
		assertEquals(instance, range1.getInstance());
		assertEquals(project, range1.getProject());
		assertEquals(31, range1.getLowerBound());
		assertEquals(37, range1.getUpperBound());
	}

	/**
	 * @throws Exception Exception.
	 */
	private static PadreObject createTestObject(final PadreID padreID) throws Exception
	{
		return new PadreObject(padreID, "dGVzdA==", "2b200a668f372eb923099cbdb250d0aa340de0163088de1e23482b1a4c50ae9b");
	}

}
