/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre.test;

import static org.junit.Assert.assertTrue;

import java.util.List;

import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.PadreGetProjects;
import org.bbaw.pdr.padre.client.PadreClient;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
*
* @author Fabian Körner
*/
public class TestPadreGetProjects
{

	private static final TestConfiguration CONFIGURATION = new TestConfigurationFromFile();

	private PadreClient _padreClient;

	/**
	 * @throws Exception Exception.
	 */
	@Before
	public final void setUp() throws Exception
	{
		PadreConfiguration.getInstance().setCredentials(CONFIGURATION.getUri(), CONFIGURATION.getUsername(), CONFIGURATION.getPassword());
		_padreClient = PadreConfiguration.getInstance().getPadreClient();

		_padreClient.createStore("31e");
		_padreClient.createStore("31f");
		_padreClient.createStore("320");
	}

	/**
	 * @throws Exception Exception.
	 */
	@After
	public final void tearDown() throws Exception
	{
		_padreClient.deleteStore("31e");
		_padreClient.deleteStore("31f");
		_padreClient.deleteStore("320");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetProjects() throws Exception
	{
		String[] expecteds = {"31e", "31f", "320"};
		List<String> actuals = new PadreGetProjects().execute();
		for (String expected : expecteds)
		{
			assertTrue(actuals.contains(expected));
		}
	}

}
