/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre.test;

import static org.junit.Assert.assertTrue;

import java.util.List;
import java.util.Vector;

import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.PadreContains;
import org.bbaw.pdr.padre.PadreWriteXml;
import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.utils.PDRObject;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
*
* @author Fabian Körner
*/
public class TestPadreWrite
{

	private static final TestConfiguration CONFIGURATION = new TestConfigurationFromFile();

	private PadreClient _padreClient;

	/**
	 * @throws Exception Exception.
	 */
	@Before
	public final void setUp() throws Exception
	{
		PadreConfiguration.getInstance().setCredentials(CONFIGURATION.getUri(), CONFIGURATION.getUsername(), CONFIGURATION.getPassword());
		_padreClient = PadreConfiguration.getInstance().getPadreClient();

		_padreClient.createStore("31e");

	}

	/**
	 * @throws Exception Exception.
	 */
	@After
	public final void tearDown() throws Exception
	{
		_padreClient.deleteStore("31e");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testWriteSingle() throws Exception
	{
		String xmlContent = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.798.000000001\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.001.798.000000001\"/></record></person>";

		PDRObject object = new PDRObject(xmlContent);

		new PadreWriteXml(object).execute();

		Boolean result = new PadreContains("pdrPo.001.798.000000001").execute();
		assertTrue(result.booleanValue());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testWriteList() throws Exception
	{
		String xmlContent0 = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.798.000000018\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.001.798.000000001\"/></record></person>";
		String xmlContent1 = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.798.000000019\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.001.798.000000001\"/></record></person>";
		String xmlContent2 = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.798.000000020\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.001.798.000000001\"/></record></person>";

		List<PDRObject> objects = new Vector<PDRObject>();
		objects.add(new PDRObject(xmlContent0));
		objects.add(new PDRObject(xmlContent1));
		objects.add(new PDRObject(xmlContent2));

		new PadreWriteXml(objects).execute();

		Boolean result0 = new PadreContains("pdrPo.001.798.000000018").execute();
		Boolean result1 = new PadreContains("pdrPo.001.798.000000019").execute();
		Boolean result2 = new PadreContains("pdrPo.001.798.000000020").execute();

		assertTrue(result0.booleanValue());
		assertTrue(result1.booleanValue());
		assertTrue(result2.booleanValue());
	}

}
