/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import org.apache.solr.common.SolrInputDocument;
import org.bbaw.pdr.utils.PDRObject;

/**
 * Implements Apache Solr's commit command.
 * @author Fabian Körner
 */
public final class SolrAdd extends AbstractSolrCommand<Object>
{

	private PDRObject _pdrObject;

	/**
	 * Constructor with PDR object.
	 * @param pdrObject PDR object.
	 * @throws SolrCommandException Could not successfully create Solr command.
	 */
	public SolrAdd(final PDRObject pdrObject) throws SolrCommandException
	{
		super();
		_pdrObject = pdrObject;
	}

	/**
	 * @see org.bbaw.pdr.solr.AbstractSolrCommand#execute()
	 * @return Null.
	 * @throws SolrCommandException Could not successfully execute Solr command.
	 */
	@Override
	public Object execute() throws SolrCommandException
	{
		try
		{
			SolrInputDocument solrInputDocument = SolrInputDocumentFactory.createSolrInputDocument(_pdrObject);
			super.getSolrServer().add(solrInputDocument);
		}
		catch (Exception cause)
		{
			throw new SolrCommandException(cause);
		}
		return null;
	}
}
