/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

/**
 * Fetches the instance ID.
 * @author Fabian Körner
 */
public final class PadreGetInstance extends AbstractPadreCommand<String>
{

	/**
	 * Returns PaDRe's instance ID.
	 * @throws PadreCommandException Could not get instance ID.
	 */
	public PadreGetInstance() throws PadreCommandException
	{
		super();
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Instance ID.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public String execute() throws PadreCommandException
	{
		try
		{
			return super.getPadreClient().instance();
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}
}
