/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.util.Collection;
import java.util.List;
import java.util.Vector;

import javax.xml.stream.XMLStreamException;

import org.apache.solr.common.SolrInputDocument;
import org.bbaw.pdr.utils.PDRObject;

/**
 * Implements Apache Solr's commit command.
 * @author Fabian Körner
 */
public final class SolrAddCollection extends AbstractSolrCommand<Object>
{

	private List<PDRObject> _pdrObjects;

	/**
	 * Constructor with a collection of PDR objects.
	 * @param pdrObjects PDR objects.
	 * @throws SolrCommandException Could not successfully create Solr command.
	 */
	public SolrAddCollection(final List<PDRObject> pdrObjects) throws SolrCommandException
	{
		super();
		_pdrObjects = pdrObjects;
	}

	/**
	 * @see org.bbaw.pdr.solr.AbstractSolrCommand#execute()
	 * @return Null.
	 * @throws SolrCommandException Could not successfully execute Solr command.
	 */
	@Override
	public Object execute() throws SolrCommandException
	{
		try
		{
			Collection<SolrInputDocument> solrInputDocuments = SolrAddCollection.transformCollection(_pdrObjects);
			super.getSolrServer().add(solrInputDocuments);
		}
		catch (Exception cause)
		{
			throw new SolrCommandException(cause);
		}
		return null;
	}

	private static List<SolrInputDocument> transformCollection(final List<PDRObject> objects) throws SolrCommandException, XMLStreamException
	{
		List<SolrInputDocument> result = new Vector<SolrInputDocument>();
		for (PDRObject pdrObject : objects)
		{
			result.add(SolrInputDocumentFactory.createSolrInputDocument(pdrObject));
		}
		return result;
	}
}
