/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.util.Iterator;

import javax.xml.namespace.QName;

import org.apache.axiom.om.OMAttribute;
import org.apache.axiom.om.OMElement;

/**
 * Solr input document with index fields specific to persons.
 * @author Fabian Körner
 */
public class SolrInputPerson extends SolrInputCommon
{

	private static final long serialVersionUID = 7070236605424058602L;

	private QName _qNameIdentifiersElement;
	private QName _qNameIdentifierElement;
	private QName _qNameConcurrencesElement;
	private QName _qNameConcurrenceElement;

	private QName _qNameProviderAttribute;
	private QName _qNamePersonAttribute;

	protected SolrInputPerson(final OMElement root)
	{
		super(root);
		this.initQNames();
		this.addSpecificIndexFields();
	}

	private void initQNames()
	{
		_qNameIdentifiersElement = super.createQNameOfElement("identifiers");
		_qNameIdentifierElement = super.createQNameOfElement("identifier");
		_qNameConcurrencesElement = super.createQNameOfElement("concurrences");
		_qNameConcurrenceElement = super.createQNameOfElement("concurrence");

		_qNameProviderAttribute = super.createQNameOfAttribute("provider");
		_qNamePersonAttribute = super.createQNameOfAttribute("person");
	}

	private void addSpecificIndexFields()
	{
		OMElement identifiersElement = super.getRoot().getFirstChildWithName(_qNameIdentifiersElement);
		if (null != identifiersElement)
		{
			addIdentifiersFields(identifiersElement);
		}

		OMElement concurrencesElement = super.getRoot().getFirstChildWithName(_qNameConcurrencesElement);
		if (null != concurrencesElement)
		{
			addConcurrencesFields(concurrencesElement);
		}
	}

	private void addIdentifiersFields(final OMElement identifiersElement)
	{
		Iterator<?> identifiers = identifiersElement.getChildrenWithName(_qNameIdentifierElement);
		OMElement identifierElement;
		OMAttribute providerAttribute;
		String identifier;
		String provider;
		String cidentifier;
		while (identifiers.hasNext())
		{
			identifierElement = (OMElement) identifiers.next();
			providerAttribute = identifierElement.getAttribute(_qNameProviderAttribute);

			identifier = identifierElement.getText();
			provider = providerAttribute.getAttributeValue();
			cidentifier = SolrInputCommon.getCombinedIndexValue(identifier, provider);

			addField("person.identifier.provider", provider);
			addField("person.identifier", identifier);
			addField("person.cidentifier", cidentifier);
		}
	}

	private void addConcurrencesFields(final OMElement concurrencesElement)
	{
		Iterator<?> concurrences = concurrencesElement.getChildrenWithName(_qNameConcurrenceElement);
		OMElement concurrenceElement;
		OMAttribute personAttribute;
		String person;
		while (concurrences.hasNext())
		{
			concurrenceElement = (OMElement) concurrences.next();
			personAttribute = concurrenceElement.getAttribute(_qNamePersonAttribute);

			person = personAttribute.getAttributeValue();

			addField("person.concurrence", person);
		}
	}
}
